/*
 * This is an example so remember to change every fake string data such as:
 * "mail.host.com", "password",	"alice@mail.com" to real-word values.
 * 
 * For additional info and faq visit: http://www.lesnikowski.com/mail
 * 
 */

using System;
using System.IO;
using Lesnikowski.Client;							// POP3 and SMTP clients
using Lesnikowski.Mail;								// Email parser
using Lesnikowski.Mail.Headers;                     // Headers
using Lesnikowski.Mail.Headers.Constants;           // Header constants

class Example1
{
	private static void Receive()
	{
		Pop3 pop3 = new Pop3();
		pop3.User = "lesnikowski";					// Set user name and password
		pop3.Password = "password";

		try
		{
			pop3.Connect("mail.host.com");			// Connect to server and login

			if (pop3.HasTimeStamp == true)			// Try APOP secure login
				pop3.APOPLogin();
			else
				pop3.Login();

			pop3.GetAccountStat();					// Get account statistics

			for(int i = 1; i <= pop3.MessageCount; i++)
			{
				try
				{
					// Receive email
                    SimpleMailMessageBuilder builder = new SimpleMailMessageBuilder();
					ISimpleMailMessage simpleMail = builder.CreateFromEml( pop3.GetMessage(i) );
		
					Console.WriteLine("-- email {0} --", i);

					// Write out email's subject
					Console.WriteLine( simpleMail.Subject );
										
					// Write out email's from.
					foreach(MailBox mb in simpleMail.From)
					{
                        // Write out name, if it was provided and address
                        Console.WriteLine("From: {0}<{1}>", mb.Name, mb.Address);
					}

					// Write out email's body.
					if (simpleMail.HtmlData != null)
						Console.WriteLine( simpleMail.HtmlDataString ); // HTML email
					else
						Console.WriteLine( simpleMail.TextDataString );	// Text email
						

					// Write out Attachments
					foreach(MimeData attachment in simpleMail.Attachments)
					{
						Console.WriteLine(attachment.FileName);
						// Save attachment to disk
						attachment.Save( @"c:\" + attachment.FileName );
					}

					// pop3.DeleteMessage(i);		// Delete message from POP3 server
				}
				catch(MailException ex)
				{
					Console.WriteLine(ex.Message);	// Invalid email format
				}
			}
		}							
		catch(ServerException ex)
		{
			Console.WriteLine(ex.Message);			// Server error
		}
		finally
		{
			pop3.Close(false);						// Close connection
		}
	}

	static private void Send()
	{
		// Use builder class to build the message
        SimpleMailMessageBuilder builder = new SimpleMailMessageBuilder();

        builder.From.Add(new MailBox("alice@mail.com", "Alice"));
        builder.To.Add(new MailBox("bob@mail.com", "Bob"));
        builder.Subject = "Test";
        builder.SetTextData("This is plain text message.");
		builder.SetHtmlData("<html><body>"+
			"This is <strong>HTML</strong> message, "+
			"with embeded image:<br />"+
			"<img src = 'cid:image1' />."+
            "</body></html>");
			
		// Read image from disk...
        MimeData image = builder.AddVisual("image.jpg");
        image.ContentType = new ContentType(MimeType.Image, MimeSubtype.Jpeg);
        image.ContentId = "image1";

        // create mail message
        ISimpleMailMessage sm = builder.Create();

		// Write email to disk, just to see how it looks.
		string eml = sm.GetSmtpData();
		string fileName = @"c:\mail.eml";
		StreamWriter sw = File.CreateText(fileName);
        sw.Write(eml);
		sw.Close();
		Console.WriteLine("Email saved in {0}.", fileName);

		// Send it
		Smtp smtp = new Smtp();
		smtp.User = "lesnikowski";					    //  Set user name and password
		smtp.Password = "password";
		try
		{
			smtp.Connect("mail.host.com");			    // Connect to server and login
            smtp.Ehlo(HeloType.EhloHelo, "yourname");   // Say hello to the server
            smtp.Login();							
			smtp.SendMessage( sm );			            // Send email message

		}							
		catch(ServerException ex)
		{
			Console.WriteLine(ex.Message);			    // Server error
		}
		finally
		{
			smtp.Close(false);						    // Close connection
		}
	}

	[STAThread]
	static void Main(string[] args)
	{
		Console.WriteLine( "Receiving..." );
		Receive();
		Console.WriteLine( "Receiving completed.\nPress enter..." );
		Console.ReadLine();

		Console.WriteLine( "Sending..." );
		Send();
		Console.WriteLine( "Sending completed.\nPress enter..." );
		Console.ReadLine();
	}
};
