'
'  This is an example so remember to change every fake string data such as:
'  "mail.host.com", "password",	"alice@mail.com" to real-word values.
'  
'  For additional info and faq visit: http://www.lesnikowski.com/mail
'  
'  Receiving:
'  Typicaly POP3 server is listening for SSL conections on port 995.
'  Use Pop3.ConnectSSL(string host) method to connect using this port.
'
'
'  Sending:
'  Typicaly SMTP server is working on port 25, when client 
'  sends STARTTLS command SSL connection is estalished.
'  Use Smtp.Connect(string host) method to connect to the server
'  and Smtp.StartTLS() to establish SSL connection.
'
'

Imports System.IO
Imports Lesnikowski.Client                          ' POP3 and SMTP clients
Imports Lesnikowski.Mail                            ' Email parser
Imports Lesnikowski.Mail.Headers                    ' Headers
Imports Lesnikowski.Mail.Headers.Constants          ' Header constants


Class Example3_SSL

    Shared Sub Receive()

        Dim pop3 As New Pop3
        pop3.User = "lesnikowski"                   ' Set user name and password
        pop3.Password = "password"

        Try
            pop3.ConnectSSL("mail.host.com")        ' Connect to server and login
            pop3.Login()
            pop3.GetAccountStat()                   ' Get account statistics

            For i As Integer = 1 To pop3.MessageCount
                Try
                    ' Receive email
                    ' Use builder class to create email message

                    Dim builder As New SimpleMailMessageBuilder()
                    Dim simpleMail As ISimpleMailMessage = builder.CreateFromEml(pop3.GetMessage(i))

                    Console.WriteLine("-- email {0} --", i)

                    ' Write out email's subject
                    Console.WriteLine(simpleMail.Subject)

                    ' Write out email's from.
                    Dim mb As MailBox
                    For Each mb In simpleMail.From
                        ' Write out name, if it was provided and address
                        Console.WriteLine("From: {0}<{1}>", mb.Name, mb.Address)
                    Next mb

                    ' Write out email's body.
                    If (simpleMail.HtmlData IsNot Nothing) Then
                        Console.WriteLine(simpleMail.HtmlDataString)   ' HTML email
                    Else
                        Console.WriteLine(simpleMail.TextDataString)   ' Text email
                    End If

                    ' Write out Attachments
                    Dim attachment As MimeData
                    For Each attachment In simpleMail.Attachments
                        Console.WriteLine(attachment.FileName)
                        ' Save attachment to disk
                        attachment.Save("c:\" + attachment.FileName)
                    Next attachment

                    ' pop3.DeleteMessage(i)		    ' Delete message from POP3 server

                Catch ex As MailException
                    Console.WriteLine(ex.Message)   ' Invalid email format
                End Try
            Next

        Catch ex As ServerException
            Console.WriteLine(ex.Message)           ' Server error
        Finally
            pop3.Close(False)                       ' Close connection
        End Try

    End Sub

    Shared Function CreateMailMessage() As ISimpleMailMessage

        Dim builder As SimpleMailMessageBuilder = New SimpleMailMessageBuilder()

        builder.From.Add(New MailBox("alice@mail.com", "Alice"))
        builder.To.Add(New MailBox("bob@mail.com", "Bob"))
        builder.Subject = "Test"
        builder.SetTextData("This is plain text message.")
        builder.SetHtmlData("<html><body>" _
            & "This is <strong>HTML</strong> message, " _
            & "with embeded image:<br />" _
            & "<img src = 'cid:image1' />." _
            & "</body></html>")

        ' Read image from disk...and add it to Visuals collection
        Dim image As MimeData = builder.AddVisual("image.jpg")
        image.ContentType = New ContentType(MimeType.Image, MimeSubtype.Jpeg)
        image.ContentId = "image1"

        ' Create mail message
        Dim sm As ISimpleMailMessage = builder.Create()

        ' Write email to disk, just to see how it looks.
        Dim str As String = sm.GetSmtpData()
        Dim fileName As String = "c:\mail.eml"
        Dim sw As StreamWriter = File.CreateText(fileName)
        sw.Write(str)
        sw.Close()
        Console.WriteLine("Email saved in {0}.", fileName)

        Return sm
    End Function


    Shared Sub Send()
        ' Create new email message
        Dim sm As ISimpleMailMessage = CreateMailMessage()

        ' Send it
        Dim smtp As Smtp = New Smtp
        smtp.User = "lesnikowski"                       ' Set user name and password
        smtp.Password = "password"

        Try
            smtp.Connect("mail.host.com")               ' Connect to server and login
            smtp.Ehlo(HeloType.EhloHelo, "yourname")    ' Say hello to the server
            smtp.StartTLS()                             ' Starts SSL connection
            smtp.Login()
            smtp.SendMessage(sm)                        ' Send email message

        Catch ex As ServerException
            Console.WriteLine(ex.Message)               ' Server error
        Finally
            smtp.Close(False)                           ' Close connection
        End Try

    End Sub

    Shared Sub Main()
        Console.WriteLine("Receiving...")
        Receive()
        Console.WriteLine("Receiving completed." + vbCrLf + "Press enter...")
        Console.ReadLine()

        Console.WriteLine("Sending...")
        Send()
        Console.WriteLine("Sending completed." + vbCrLf + "Press enter...")
        Console.ReadLine()
    End Sub


End Class